/**
 * Renderer for the list of tiles
 */

import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.List;

public class BlockListRenderer extends JPanel implements ListCellRenderer
{
  private final Dimension preferredSize = new Dimension( 64, 18 );
  private String text  = "";
  private BufferedImage image = null;
  private Color  background;

  private static BufferedImage scratch = 
    new BufferedImage( 16, 16, BufferedImage.TYPE_INT_RGB );

  public BlockListRenderer()
  {
    super();
    setOpaque( true );
  }

  public Component getListCellRendererComponent( JList list,
                                                 Object value,
                                                 int index,
                                                 boolean isSelected,
                                                 boolean cellHasFocus)
  {
    text  = String.valueOf( index );
    image = (BufferedImage) value;

    background = isSelected ? Color.yellow : Color.white;
    return this;
  }

  public Dimension getPreferredSize()
  {
    return preferredSize;
  }

  protected void paintComponent(Graphics g)
  {
    int h = g.getFontMetrics().getAscent();
    int w = g.getFontMetrics().stringWidth( "888" );

    g.setColor( background );
    g.fillRect( 0, 0, getWidth(), getHeight());

    g.setColor( Color.black );
    g.drawString( text, 1, ((18 + h) / 2) - 1 );

    g.setColor( Color.black );

    if ( image != null )
    {
      int width  = image.getWidth();
      int height = image.getHeight();
      int[] data = new int[width * height];
      int[] mask = new int[width * height];
      
      image.getRGB( 0, 0, width, height, data, 0, width );

      // Force the data image to be opaque and make the mask data
      // to a black and white image
      for ( int i = 0; i < width * height; i++ ) {
        mask[i] = (( data[i] & 0xFF000000 ) != 0 ) ? 0xFF000000 : 0xFFFFFFFF;
        data[i] = data[i] | 0xFF000000;
      }

      scratch.setRGB( 0, 0, width, height, data, 0, width );
      g.drawImage( scratch, w + 4,  1, Color.white, null );

      scratch.setRGB( 0, 0, width, height, mask, 0, width );
      g.drawImage( scratch, w + 21, 1, Color.white, null );
    }
    else
    {
      g.fillRect( w + 4,  1, 16, 16 );
      g.fillRect( w + 21, 1, 16, 16 );
    }   
  }
}
